#!/usr/bin/env node

var inquirer = require( 'inquirer' ),
	figlet   = require( 'figlet' ),
	chalk    = require( 'chalk' ),
	clear    = require( 'clear' ),
	clui     = require( 'clui' ),
	fs       = require( 'fs-extra' );

var Spinner = clui.Spinner;
var countdown = new Spinner( chalk.cyan( 'Creating new project...' ) );

const { questions, finalConfirmation } = require( './questions' );

clear();

function init ()
{
	figlet( 'DI Builder', {
		horizontalLayout: 'fitted'
	}, function ( err, data ) {
		if ( err )
		{
			console.log( 'Something went wrong...' );
			console.dir( err );
			return;
		}
		console.log( chalk.blue( data ) );

		requestInformation ();
	});
}

function requestInformation ()
{
	inquirer.prompt( questions ).then( function ( answers ) {
		console.log( '\nPreview:' );
		console.log( chalk.cyan( JSON.stringify( answers, null, '  ' ) ), '\n' );

		inquirer.prompt( finalConfirmation ).then( function ( confirmAnswer ) {
			if ( confirmAnswer.isCorrect )
				createProject( answers );
			else
				requestInformation();
		} );
	});
}

function createProject ( params )
{
	countdown.start();

	// Start downloading the repository
	setInterval( function () {
		fs.copy( `${ __dirname }/templates/${ params.type }_${ params.reactTemplate }/`, './', function ( error ) {
			if ( error ) return console.log( chalk.red( error ) );
			console.log( chalk.green( "\nDone! You've got a new project" ) );

			process.exit( 0 );
		} );
	}, 1000 );
}

init();
